@@ -224,6 +224,10 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
               help='Generate asimov data with POI set at the specified value.')
 @click.option('--poi_profile', type=float, default=None,
               help='Perform NP profiling with POI set at the specified value.')
+@click.option('--globs_np_matching/--no_globs_np_matching', default=True, show_default=True,
+              help='Match the values of nuisance parameters and the corresponding global '
+                   'observables when generating the asimov data. This is important for making '
+                   'sure the asimov data has the (conditional) minimal NLL.')
 @click.option('--conditional_mle/--undonditional_mle', default=True, show_default=True,
               help='Perform conditional maximum likelihood estimation. This option is effective '
                    'only if poi_profile is specified. If True, best-fit values are obtained for '
